// load-clip
// © jonas.sundstrom@kirilla.com

#define DEBUG 0
#include <Debug.h>

#include <stdio.h>
#include <stdlib.h>

#include <Application.h>
#include <Roster.h>
#include <String.h>
#include <File.h>
#include <Clipboard.h>
#include <FindDirectory.h>
#include <Path.h>
#include <string.h>

#include "load-clip-app.h"

int	exitvalue;

int main()
{
	exitvalue = EXIT_SUCCESS;

	new ClipApp();
	be_app	-> Run();
	delete	be_app;

	return (exitvalue);
}

ClipApp::ClipApp	(void)
 : BApplication	("application/x-vnd.Kirilla-load-clip")
{
	got_arguments	=	false;	
}

ClipApp::~ClipApp	(void)
{

}

void 
ClipApp::ArgvReceived	(int32 argc, char **argv)
{
	got_arguments	=	true;

	BString argument = argv[1];
	
	if (argument == "--help")
	{
		Help();
		return;
	}
	
	Load(argv[1]);
}

void
ClipApp::ReadyToRun	(void)
{
	if (! got_arguments)
		Load(NULL);
		
	be_app->PostMessage(B_QUIT_REQUESTED);
}


void
ClipApp::Help	(void)
{
	printf(	"load-clip 1.0 (c) jonas.sundstrom@kirilla.com\n\n"

			"Syntax:  load-clip [path to file]\n\n"

			"If no path is specified, a default location will be used.\n"
			"('temp-clipboard', in your B_USER_SETTINGS_DIRECTORY)\n\n"
			
			"Options:\n"
			"--help          Display this marvelous help text.\n\n");
}

void
ClipApp::Load	(char * path)
{
	status_t	status	=	B_OK;
	
	// create BFile
	BFile	file;
	
	if (path == NULL)
	{
		// default location
		BPath path;
		find_directory(B_USER_SETTINGS_DIRECTORY, & path);
		
		path.SetTo(path.Path(), "temp-clipboard");
		
		status	=	file.SetTo(path.Path(), B_READ_ONLY);
	}
	else
	{
		// user-specified path
		status	=	file.SetTo(path, B_READ_ONLY);
	}
	
	if (status != B_OK)
	{
		printf("load-clip failed ");
	
		if (status == B_PERMISSION_DENIED)
			printf("Permission denied.\n");
			
		if (status == B_ENTRY_NOT_FOUND)
			printf("File does not exist.\n");
		
		printf("(%s)\n", strerror(status));
		
		exitvalue = EXIT_FAILURE;
		return;
	}
	
	// get BMesage from clip
	BMessage	filed_clip;
	
	status	=	filed_clip.Unflatten(& file);
	
	if (status != B_OK)
	{
		printf("load-clip failed. ");
		printf("(%s)\n", strerror(status));
		
		exitvalue = EXIT_FAILURE;
		return;
	}
	

	// stuff clip into clipboard
	
	BMessage	*	clip	=	NULL;
	
	if (be_clipboard->Lock())
	{
		be_clipboard->Clear();
		
		clip = be_clipboard->Data();
		
		*clip = filed_clip;
		
		status = be_clipboard->Commit();
		
		if (status != B_OK)
		{
			be_clipboard->Unlock();

			exitvalue = EXIT_FAILURE;
			return;
		}
	
		be_clipboard->Unlock();
	}
	else
	{
		printf("load-clip failed. Could not lock clipboard.\n");
		
		exitvalue = EXIT_FAILURE;
		return;
	}
	

	printf("Clip loaded.\n");
}
