// make-clip
// © jonas.sundstrom@kirilla.com

#define DEBUG 0
#include <Debug.h>

#include <stdio.h>
#include <stdlib.h>
#include <iostream>

#include <Application.h>
#include <Roster.h>
#include <String.h>
#include <Clipboard.h>
#include <string.h>

#include "make-clip-app.h"

int	exitvalue;

int main()
{
	exitvalue = EXIT_SUCCESS;

	new ClipApp();
	be_app	-> Run();
	delete	be_app;

	return (exitvalue);
}

ClipApp::ClipApp	(void)
 : BApplication	("application/x-vnd.Kirilla-make-clip")
{
	got_arguments	=	false;	
}

ClipApp::~ClipApp	(void)
{

}

void 
ClipApp::ArgvReceived	(int32 argc, char **argv)
{
	got_arguments	=	true;

	BString argument = argv[1];
	
	if (argument == "--help")
	{
		Help();
		return;
	}
	
	Make(argv[1]);
}

void
ClipApp::ReadyToRun	(void)
{
	if (! got_arguments)
		Make(NULL);
		
	be_app->PostMessage(B_QUIT_REQUESTED);
}


void
ClipApp::Help	(void)
{
	printf(	"make-clip 1.0 (c) jonas.sundstrom@kirilla.com\n\n"

			"Syntax:  make-clip [string]\n\n"

			"If no string is specified, \n"
			"make-clip will read from standard input.\n\n"
			
			"Options:\n"
			"--help          Display this marvelous help text.\n\n");
}

void
ClipApp::Make	(char * a_string)
{
	status_t	status	=	B_OK;
	BString		std_input;
	
	if (a_string == NULL)
	{
		// read from standard input
		char c;
		while ((c = cin.get()) != EOF)
		{
			std_input	+=	c;
		}
		
		a_string = std_input.String();
	}
	
	// get clipboard BMessage
	
	BMessage	*	clip	=	NULL;
	
	if (be_clipboard->Lock())
	{
		be_clipboard->Clear();
		
		clip = be_clipboard->Data();

		// add data to clipboard
			
		clip->AddData("text/plain", B_MIME_TYPE, a_string, strlen(a_string));			
		
		status = be_clipboard->Commit();
		
		if (status != B_OK)
		{
			be_clipboard->Unlock();
			exitvalue = EXIT_FAILURE;
			return;
		}
	
		be_clipboard->Unlock();
	}
	else
	{
		printf("make-clip failed. Could not lock clipboard.\n");
		
		exitvalue = EXIT_FAILURE;
		return;
	}
	

	printf("Data added to clipboard.\n");
}
