// print-clip
// © jonas.sundstrom@kirilla.com

#define DEBUG 0
#include <Debug.h>

#include <stdio.h>
#include <stdlib.h>

#include <Application.h>
#include <Roster.h>
#include <String.h>
#include <File.h>
#include <Clipboard.h>
#include <FindDirectory.h>
#include <Path.h>
#include <string.h>

#include "print-clip-app.h"

int	exitvalue;

int main()
{
	exitvalue = EXIT_SUCCESS;

	new ClipApp();
	be_app	-> Run();
	delete	be_app;
	
	return (exitvalue);
}

ClipApp::ClipApp	(void)
 : BApplication	("application/x-vnd.Kirilla-print-clip")
{
	got_arguments	=	false;	
}

ClipApp::~ClipApp	(void)
{

}

void 
ClipApp::ArgvReceived	(int32 argc, char **argv)
{
	got_arguments	=	true;

	BString argument = argv[1];
	
	if (argument == "--help")
		Help();
	
	if (argument == "--debug")
		Print(true);
}

void
ClipApp::ReadyToRun	(void)
{
	if (! got_arguments)
		Print(false);
		
	be_app->PostMessage(B_QUIT_REQUESTED);
}


void
ClipApp::Help	(void)
{
	printf(	"print-clip 1.0 (c) jonas.sundstrom@kirilla.com\n\n"

			"Syntax:  print-clip\n\n"

			"Purpose: display text contents of clipboard.\n\n"
			
			"Options:\n"
			"--debug         Print clipboard BMessage.\n"
			"--help          Display this marvelous help text.\n\n");
}

void
ClipApp::Print	(bool a_debug)
{
	// get clip & print contents 
	// (or the entire clip, in case of --debug)
	BMessage	*	clip;
	
	if (be_clipboard->Lock())
	{
		clip = be_clipboard->Data();
	
		if (a_debug)
			clip->PrintToStream();
		else
		{
			const char *	text;
			int32 			text_len;
			BString			out_string;
			
			clip->	FindData("text/plain", B_MIME_TYPE, (const void **)&text, &text_len);
			
			if (text != NULL)
				out_string.SetTo(text, text_len);
			
			printf("%s\n", out_string.String());
		}	
	
		be_clipboard->Unlock();
	}
	else
	{
		printf("print-clip failed. Could not lock clipboard.\n");
		exitvalue = EXIT_FAILURE;
		return;
	}
}

