// save-clip
// © jonas.sundstrom@kirilla.com

#define DEBUG 0
#include <Debug.h>

#include <stdio.h>
#include <stdlib.h>

#include <Application.h>
#include <Roster.h>
#include <String.h>
#include <File.h>
#include <Clipboard.h>
#include <FindDirectory.h>
#include <Path.h>
#include <string.h>

#include "save-clip-app.h"

int	exitvalue;

int main()
{
	exitvalue = EXIT_SUCCESS;
	
	new ClipApp();
	be_app	-> Run();
	delete	be_app;
	
	return (exitvalue);
}

ClipApp::ClipApp	(void)
 : BApplication	("application/x-vnd.Kirilla-save-clip")
{
	got_arguments	=	false;	
}

ClipApp::~ClipApp	(void)
{

}

void 
ClipApp::ArgvReceived	(int32 argc, char **argv)
{
	got_arguments	=	true;

	BString argument = argv[1];
	
	if (argument == "--help")
	{
		Help();
		return;
	}
	
	Save(argv[1]);
}

void
ClipApp::ReadyToRun	(void)
{
	if (! got_arguments)
		Save(NULL);
		
	be_app->PostMessage(B_QUIT_REQUESTED);
}


void
ClipApp::Help	(void)
{
	printf(	"save-clip 1.0 (c) jonas.sundstrom@kirilla.com\n\n"

			"Syntax:  save-clip [path to file]\n\n"

			"WARNING: save-clip will erase any previous file at the location.\n\n"

			"If no path is specified, a default location will be used.\n"
			"('temp-clipboard', in your B_USER_SETTINGS_DIRECTORY)\n\n"
			
			"Options:\n"
			"--help          Display this marvelous help text.\n\n");
}

void
ClipApp::Save	(char * path)
{
	status_t	status	=	B_OK;
	
	// create BFile
	BFile	file;
	
	if (path == NULL)
	{
		// default location
		BPath path;
		find_directory(B_USER_SETTINGS_DIRECTORY, & path);
		
		path.SetTo(path.Path(), "temp-clipboard");
		
		status	=	file.SetTo(path.Path(), B_WRITE_ONLY | B_CREATE_FILE | B_ERASE_FILE);
	}
	else
	{
		// user-specified path
		status	=	file.SetTo(path, B_WRITE_ONLY | B_CREATE_FILE | B_ERASE_FILE);
	}
	
	if (status != B_OK)
	{
		if (status == B_PERMISSION_DENIED)
			printf("Save-clip failed. Permission denied.\n");
			
		if (status == B_BAD_VALUE)
			printf("Save-clip failed. Path does not exist.\n");
		
		printf("(%s)\n", strerror(status));
		
		exitvalue = EXIT_FAILURE;
		return;
	}
	
	// get clip
	BMessage	*	clip;
	
	if (be_clipboard->Lock())
	{
		clip = be_clipboard->Data();
	
		be_clipboard->Unlock();
	}
	else
	{
		printf("Save-clip failed. Could not lock clipboard.\n");
		
		exitvalue = EXIT_FAILURE;
		return;
	}
	
	// flatten clip to file
	
	status	=	clip->	Flatten(& file);
	
	if (status != B_OK)
	{
		if (status == B_NO_MEMORY)
			printf("Save-clip failed. Out of diskspace?\n");
			
		if (status == B_BAD_VALUE)
			printf("Save-clip failed. Unknown error.\n");
			
		printf("(%s)\n", strerror(status));
		
		exitvalue = EXIT_FAILURE;
		return;
	}
	
	printf("Clip saved.\n");
}
